@@ -1,5 +1,5 @@
 /*
- * $Id: ngrep.c,v 1.9 2001/02/27 06:09:25 jpr5 Exp $
+ * $Id: ngrep.c,v 1.13 2001/04/22 23:27:16 jpr5 Exp $
  *
  * Copyright (c) 2001  Jordan Ritter <jpr5@darkridge.com>
  *
@@ -15,6 +15,7 @@
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <net/if.h>
+#include <sys/tty.h>
 #endif
 
 #if defined(OSF1)
@@ -32,6 +33,12 @@
 #include <ctype.h>
 #endif
 
+#if defined(AIX)
+#include <sys/machine.h>
+#include <sys/types.h>
+#include <netinet/in.h>
+#include <time.h>
+#endif
 
 #include <netinet/ip.h>
 #include <netinet/tcp.h>
@@ -55,7 +62,7 @@
 #include "ngrep.h"
 
 
-static char rcsver[] = "$Revision: 1.9 $";
+static char rcsver[] = "$Revision: 1.13 $";
 
 int snaplen = 65535, promisc = 1, to = 1000;
 int show_empty = 0, show_hex = 0, quiet = 0;
@@ -147,6 +154,9 @@ int main(int argc, char **argv) {
     case 'e':
       show_empty++;
       break;
+    case 'p':
+      promisc = 0;
+      break;
     case 'q':
       quiet++;
       break;
@@ -393,7 +403,13 @@ int main(int argc, char **argv) {
 void process(u_char *data1, struct pcap_pkthdr* h, u_char *p) {
   struct ip* ip_packet = (struct ip *)(p + link_offset);
 
+#if defined(AIX)
+#undef ip_hl
+  unsigned ip_hl = ip_packet->ip_ff.ip_fhl*4;
+#else
   unsigned ip_hl = ip_packet->ip_hl*4;
+#endif
+
   unsigned ip_off = ntohs(ip_packet->ip_off);
   unsigned fragmented = ip_off & (IP_MF | IP_OFFMASK);
   unsigned frag_offset = fragmented?(ip_off & IP_OFFMASK) * 8:0;
@@ -773,8 +789,8 @@ void update_windowsize(int e) {
 
 
 void usage(int e) {
-  printf("usage: ngrep <-hXViwqevxlDtT> <-IO pcap_dump> <-n num> <-d dev> <-A num>\n"
-	 "                              <match expression> <bpf filter>\n");
+  printf("usage: ngrep <-hXViwqpevxlDtT> <-IO pcap_dump> <-n num> <-d dev> <-A num>\n"
+	 "                               <match expression> <bpf filter>\n");
   exit(e);
 }
 
